==> org.eclipse.reddeer.swt.source_2.4.0.v20181212-1430.jar: org/eclipse/reddeer/swt/condition/TreeContainsItem.java <==
/*******************************************************************************
 * Copyright (c) 2017 Red Hat, Inc and others.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Red Hat, Inc - initial API and implementation
 *******************************************************************************/
package org.eclipse.reddeer.swt.condition;

import java.util.Arrays;

import org.eclipse.reddeer.common.condition.AbstractWaitCondition;
import org.eclipse.reddeer.swt.api.Tree;
import org.eclipse.reddeer.swt.impl.tree.DefaultTreeItem;

public class TreeContainsItem extends AbstractWaitCondition {

	private Tree tree;
	private String[] itemPath;
	private DefaultTreeItem resultItem;

	/**
	 * Constructs TreeContainsItem wait condition. Condition is met when the
	 * specified tree contains the tree item with specified text.
	 * 
	 * @param tree tree where to look for an item
	 * @param itemPath path to an item
	 */
	public TreeContainsItem(Tree tree, String... itemPath) {
		this.tree = tree;
		this.itemPath = itemPath;
	}

	@Override
	public boolean test() {
		try{
			this.resultItem = new DefaultTreeItem(tree, itemPath);
			return true;
		} catch (Exception e) {
			this.resultItem = null;
			return false;
		}
	}

	@Override
	public String description() {
		return "tree contains item '" + Arrays.toString(itemPath);
	}
	
	@SuppressWarnings("unchecked")
	@Override 
	public DefaultTreeItem getResult() {
		return this.resultItem;
	}

}

==> org.eclipse.reddeer.swt.source_4.5.0.v20230308-1253.jar: org/eclipse/reddeer/swt/condition/TreeContainsItem.java <==
/*******************************************************************************
 * Copyright (c) 2017 Red Hat, Inc and others.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Red Hat, Inc - initial API and implementation
 *******************************************************************************/
package org.eclipse.reddeer.swt.condition;

import java.util.Arrays;

import org.eclipse.reddeer.common.condition.AbstractWaitCondition;
import org.eclipse.reddeer.swt.api.Tree;
import org.eclipse.reddeer.swt.impl.tree.DefaultTree;
import org.eclipse.reddeer.swt.impl.tree.DefaultTreeItem;

public class TreeContainsItem extends AbstractWaitCondition {

	private Tree tree;
	private String[] itemPath;
	private DefaultTreeItem resultItem;

	/**
	 * Constructs TreeContainsItem wait condition. Condition is met when the
	 * default tree contains the tree item with specified text.
	 * 
	 * @param itemPath path to an item
	 */
	public TreeContainsItem(String... itemPath) {
		this.tree = new DefaultTree();
		this.itemPath = itemPath;
	}
	
	/**
	 * Constructs TreeContainsItem wait condition. Condition is met when the
	 * specified tree contains the tree item with specified text.
	 * 
	 * @param tree tree where to look for an item
	 * @param itemPath path to an item
	 */
	public TreeContainsItem(Tree tree, String... itemPath) {
		this.tree = tree;
		this.itemPath = itemPath;
	}
	
	@Override
	public boolean test() {
		try{
			this.resultItem = new DefaultTreeItem(tree, itemPath);
			return true;
		} catch (Exception e) {
			this.resultItem = null;
			return false;
		}
	}

	@Override
	public String description() {
		return "tree contains item '" + Arrays.toString(itemPath);
	}
	
	@SuppressWarnings("unchecked")
	@Override 
	public DefaultTreeItem getResult() {
		return this.resultItem;
	}

}
